#
# spec file for package dynare
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
# GCC 9 or higher required
%define gccver 9
# Sphinx in Leap 15.x is too old
%bcond_with doc
%else
%define gccver %{nil}
%bcond_without doc
%endif
Name:           dynare
Version:        5.4
Release:        1.1
Summary:        A platform for handling a wide class of economic models
License:        GPL-3.0-or-later
URL:            https://www.dynare.org/
Source:         https://www.dynare.org/release/source/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM dynare-no-return-in-non-void-function.patch badshah400@gmail.com -- Return trivial value from a function that is not declared as returning void
Patch0:         dynare-no-return-in-non-void-function.patch
# PATCH-FIX-UPSTREAM dynare-add-missing-include.patch -- Add missing includes, gcc 13 exposed
Patch1:         dynare-add-missing-include.patch
BuildRequires:  fdupes
BuildRequires:  gcc%{gccver}-c++
BuildRequires:  gcc%{gccver}-fortran
BuildRequires:  lapack-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  suitesparse-devel
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(matio)
BuildRequires:  pkgconfig(octave)
%if %{with doc}
# SECTION Required for docs
BuildRequires:  python3-Sphinx-latex
BuildRequires:  texlive-beamer
BuildRequires:  texlive-bibtex-bin
BuildRequires:  texlive-latex-bin
BuildRequires:  tex(ccicons.sty)
BuildRequires:  tex(doi.sty)
BuildRequires:  tex(elsarticle.cls)
BuildRequires:  tex(epsf.sty)
BuildRequires:  tex(fullpage.sty)
BuildRequires:  tex(psfrag.sty)
BuildRequires:  tex(tgtermes.sty)
# /SECTION
%endif

%description
Dynare is a software platform for handling a wide class of economic models, in
particular dynamic stochastic general equilibrium (DSGE) and overlapping
generations (OLG) models.

%package doc-pdf
Summary:        Documentation for dynare in PDF format
BuildArch:      noarch

%description doc-pdf
This package provides documentation for %{name} in PDF format.

%package doc-html
Summary:        Documentation for dynare in HTML format
BuildArch:      noarch

%description doc-html
This package provides documentation for %{name} in HTML format.

%prep
%autosetup -p1

%build
autoreconf -fvi
%if 0%{?suse_version} < 1550
export CXX=g++-%{gccver}
export CXXFLAGS+=' -std=c++17'
%endif
%configure \
  --docdir=%{_docdir}/%{name} \
  --disable-matlab \
  --disable-mex-kalman-steady-state \
  %{!?with_doc:--disable-doc} \
  %{nil}
%make_build
%if %{with doc}
%make_build pdf html
%endif

%install
%make_install
%fdupes %{buildroot}%{_libdir}/%{name}/
%if %{with doc}
%fdupes %{buildroot}%{_docdir}/%{name}/dynare-manual.html/
rm %{buildroot}%{_docdir}/%{name}/dynare-manual.html/.buildinfo
%endif

%files
%license license.txt
%doc CONTRIBUTING.md NEWS.md README.md
%{_bindir}/dynare++
%{_bindir}/dynare-preprocessor
%{_libdir}/dynare/

%if %{with doc}
%files doc-pdf
%{_docdir}/%{name}/*.pdf
%{_docdir}/%{name}/dynare++/

%files doc-html
%{_docdir}/%{name}/dynare-manual.html/
%endif

%changelog
* Wed Apr 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.4:
  * Estimation:
  - The load_results_after_load_mh option would not find the
    location of the results file
  - The computation of prior/posterior statistics would crash if
    the value of the filter step_ahead option was greater than 1
    without requesting a forecast or the smoother
  - NaN or complex parameters returned by steady state files
    were not correctly handled
  - analytical_derivation could be triggered with
    endogenous_prior but would not take the endogenous prior
    into account for the Jacobian and Hessian
  * OccBin:
  - Running the calib_smoother command with
    smoother_inversion_filter would crash unless
    likelihood_inversion_filter was also specified
  - Running the piecewise Kalman smoother would crash if an
    error was encountered during computation of the decision
    rules
  * PAC equation estimation through iterative OLS would crash if
    the auxiliary model contained a constant.
  * The variable label was incorrect for leads and lags of
    exogenous variables in the display of decision rules and in
    the model_info command.
  * Declaring a trend_var variable while not having a
    var(deflator=...) statement would cause the preprocessor to
    crash.
  * Macro processor: error messages following a @#define,
    @#include or @#includepath directive could in some cases point
    to a line number off by 1.
  * Perfect foresight simulations: the debug option would not
    preserve sparsity, causing out of memory errors.
- Make doc packages noarch.
* Mon Apr 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add dynare-add-missing-include.patch: Add missing includes, now
  exposed by gcc 13.
* Fri Dec 30 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.3:
  * Long list of changes, see
    https://www.dynare.org/new-dynare-release/dynare-5.3-released/
- Remove upstream patches:
  * dynare-5.1-gcc-12.patch
  * dynare-octave7-compat.patch
* Mon Jun 27 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add dynare-5.1-gcc-12.patch: Fix build with gcc 12.
* Tue Apr 26 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1:
  * Long list of changes, see
    <https://www.dynare.org/new-dynare-release/dynare-5.1-released/>.
- Add dynare-octave7-compat.patch: git commits from upstream to
  support building against octave 7.1; patch touches build files,
  so add BuildRequires: libtool and run autoreconf before
  configure.
* Wed Jan 12 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add dynare-no-return-in-non-void-function.patch: Return trivial
  value from a function that is not declared as returning void.
